"""
pygitscrum argparse gestion
"""

import argparse
import sys


def compute_args():
    """
    check args and return them
    """
    my_parser = argparse.ArgumentParser(
        description="pymd5search loops and tries to find a string which equals to itself when encoded with the md5 hash function",
        epilog="""
        Full documentation at: <https://github.com/thib1984/pymd5search>.
        Report bugs to <https://github.com/thib1984/pymd5search/issues>.
        MIT Licence.
        Copyright (c) 2021 thib1984.
        This is free software: you are free to change and redistribute it.
        There is NO WARRANTY, to the extent permitted by law.
        Written by thib1984.""",
    )
    my_parser.add_argument(
        "-u",
        "--update",
        action="store_true",
        help="update pymd5search",
    )       
    args = my_parser.parse_args()
    return args



"""
pymd5search use case
"""

import secrets
import hashlib

def find():
    record = 0
    while True:
        my_string = secrets.token_hex(16)
        my_md5 = hashlib.md5(my_string.encode('utf-8')).hexdigest()
        compare = ""
        compteur = 0
        for x, y in zip(my_string, my_md5):
            if x == y:
                compare = compare + x
                compteur = compteur + 1
            else:
                compare = compare + "."    
        if compteur > record:
            print(my_string)
            print(my_md5)
            print(compare)
            record = compteur
            print("New record with " + str(record) + " commons characters")
            print("")


"""
pymd5search init
"""


from pymd5search.args import compute_args
from pymd5search.pymd5search import find
from pymd5search.update import update

def pymd5search():
    """
    pymd5search entry point
    """
    args = compute_args()
    find()
